@@ -186,7 +186,7 @@ common.frame <- function(formula, data, family)
     #### Design matrix
     ## Create the matrix
     X <- try(suppressWarnings(model.matrix(object=attr(frame, "terms"), data=frame)), silent=TRUE)
-    if(class(X)=="try-error") stop("the covariate matrix contains inappropriate values.", call.=FALSE)
+    #if(class(X)=="try-error") stop("the covariate matrix contains inappropriate values.", call.=FALSE)
     if(sum(is.na(X))>0) stop("the covariate matrix contains missing 'NA' values.", call.=FALSE)
     
     n <- nrow(X)
@@ -258,14 +258,13 @@ common.frame <- function(formula, data, family)
         int.check <- n*J - n.miss - sum(ceiling(Y)==floor(Y), na.rm=TRUE)
         if(int.check > 0) stop("the response variable has non-integer values.", call.=FALSE)
         if(min(Y, na.rm=TRUE)<0) stop("the response variable has negative values.", call.=FALSE)
-    }
-    else
+    }else
     {}
     
 
     #### Offset variable
     offset <- try(model.offset(frame), silent=TRUE)
-    if(class(offset)=="try-error")   stop("the offset is not numeric.", call.=FALSE)
+    #if(class(offset)=="try-error")   stop("the offset is not numeric.", call.=FALSE)
         if(family=="multinomial")
         {
             if(is.null(offset))  offset <- array(0,c(n, (J-1)))
@@ -319,7 +318,7 @@ common.frame.localised <- function(formula, data, family, trials)
     
     #### Offset variable
     offset <- try(model.offset(frame), silent=TRUE)
-    if(class(offset)=="try-error")   stop("the offset is not numeric.", call.=FALSE)
+    #if(class(offset)=="try-error")   stop("the offset is not numeric.", call.=FALSE)
     if(is.null(offset))  offset <- rep(0,n)
     if(sum(is.na(offset))>0) stop("the offset has missing 'NA' values.", call.=FALSE)
     if(!is.numeric(offset)) stop("the offset variable has non-numeric values.", call.=FALSE)
@@ -327,7 +326,7 @@ common.frame.localised <- function(formula, data, family, trials)
     
     #### Design matrix - Create and then adapt to remove the intercept term
     X <- try(suppressWarnings(model.matrix(object=attr(frame, "terms"), data=frame)), silent=TRUE)
-    if(class(X)=="try-error") stop("the covariate matrix contains inappropriate values.", call.=FALSE)
+    #if(class(X)=="try-error") stop("the covariate matrix contains inappropriate values.", call.=FALSE)
     if(sum(is.na(X))>0) stop("the covariate matrix contains missing 'NA' values.", call.=FALSE)
     ptemp <- ncol(X)
     
