@@ -27,7 +27,7 @@ print.CARBayes <- function(x,...)
         cat("#### Results\n")
         cat("############\n")
         cat("Posterior quantities and DIC\n\n")
-        print(x$summary.results)
+        print(x$summary.results[ ,-c(4,5)])
         cat("\nDIC = ", x$modelfit[1], "     ", "p.d = ", x$modelfit[2], "     ", "LMPL = ", round(x$modelfit[5],2),"\n")
 
             if(length(x$localised.structure[[2]])>1)
@@ -58,7 +58,7 @@ print.CARBayes <- function(x,...)
         cat("#### Results\n")
         cat("############\n")
         cat("Posterior quantities and DIC\n\n")
-        print(x$summary.results)
+        print(x$summary.results[ ,-c(4,5)])
         cat("\nDIC = ", x$modelfit[1], "     ", "p.d = ", x$modelfit[2], "     ", "LMPL = ", round(x$modelfit[5],2),"\n")
         cat("\nNumber of clusters with the number of data points in each one\n")
         print(table(paste("group", x$localised.structure, sep="")))
@@ -91,7 +91,7 @@ print.CARBayes <- function(x,...)
         cat("#### Results\n")
         cat("############\n")
         cat("Posterior quantities and DIC\n\n")
-        print(x$summary.results)
+        print(x$summary.results[ ,-c(4,5)])
         cat("\nDIC = ", x$modelfit[1], "     ", "p.d = ", x$modelfit[2], "     ", "LMPL = ", round(x$modelfit[5],2),"\n")
      }
 return(invisible(x))        
